@@ -1,5 +1,4 @@
-#[cfg_attr(target_os = "netbsd", allow(unused_imports))]
-#[cfg_attr(target_os = "freebsd", allow(unused_imports))]
+#[cfg(target_os = "windows")]
 pub use self::cell::{DisplayWidth, TextCell, TextCellContents};
 pub use self::escape::escape;
 
